@@ -10,7 +10,7 @@ from email.MIMEText import MIMEText
 from email.MIMEAudio import MIMEAudio
 from email.MIMEBase import MIMEBase
 from email.MIMEImage import MIMEImage
-from Acquisition import aq_inner,aq_parent
+from Acquisition import aq_chain, aq_inner,aq_parent
 
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.utils import safe_unicode
@@ -262,10 +262,10 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         price = form.get(field)
         MERCHANT_ID = str(self.getMerchant_id())
         AMOUNT = price
-        order_number = self.getNext_order_number()
-        ORDER_NUMBER = str(order_number)
-        # Increase next_order_number by one.
-        self.setNext_order_number(order_number + 1)
+#        order_number = self.getNext_order_number()
+#        ORDER_NUMBER = str(order_number)
+#        # Increase next_order_number by one.
+#        self.setNext_order_number(order_number + 1)
         ORDER_DESCRIPTION = self.order_description(fields, REQUEST)
         CURRENCY = 'EUR'
 #        portal = getToolByName(self, 'portal_url').getPortalObject()
@@ -347,8 +347,15 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         return self.REQUEST.RESPONSE.redirect(url)
 
     def order_description(self, fields, REQUEST=None):
-        self.displayInputs(REQUEST)
-        values = [safe_unicode(item.get('value')) for item in self.displayInputs(REQUEST)]
+#        self.displayInputs(REQUEST)
+        parent = aq_parent(self)
+        labels = [parent[id].Title() for id in self.getOrder_description()]
+#        values = [safe_unicode(item.get('value')) for item in self.displayInputs(REQUEST) if item.get('label') in labels]
+        items = {}
+        for item in self.displayInputs(REQUEST):
+            items.update({item.get('label'):item.get('value')})
+#        items = [{item.get('label'):item.get('value')} for item in self.displayInputs(REQUEST)]
+        values = [safe_unicode(items.get(label)) for label in labels]
 #        form = self.REQUEST.form
 #        values = [safe_unicode(form.get(key, '')) for key in self.getOrder_description()]
         res = u','.join(values)
@@ -477,10 +484,8 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter, FormThanksPage):
         return obj.getId()
 
     def field_ids(self):
-        catalog = getToolByName(self, 'portal_catalog')
-        parent = aq_parent(aq_inner(self))
-        ids = [obj.id for obj in parent.contentValues() if isinstance(obj, BaseFormField)]
+        folder = [obj for obj in aq_chain(aq_inner(self)) if hasattr(obj, 'portal_type') and obj.portal_type == 'FormFolder'][0]
+        ids = [obj.id for obj in folder.contentValues() if isinstance(obj, BaseFormField)]
         return ids
 
-#registerType(PFGVerkkomaksut)
 registerATCT(PFGVerkkomaksut, PROJECTNAME)
